#
# spec file for package python3-espressomd
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2014 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Build with OpenMPI
%if 0%{?sle_version} == 0
%define mpiver  openmpi2
%else
%if 0%{?sle_version} <= 120300
%define mpiver  openmpi
%else
  %if 0%{?sle_version} <= 150000
  %define mpiver  openmpi2
  %else
  %define mpiver  openmpi3
  %endif
%endif
%endif

%define pkgname espresso
%define modname %{pkgname}md
Name:           python3-%{modname}
Version:        4.1.2
Release:        4.2
Summary:        Parallel simulation software for soft matter research
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Chemistry
URL:            http://espressomd.org
Source:         https://github.com/%{modname}/%{pkgname}/releases/download/%{version}/%{pkgname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 3427.patch - fix test on 586 - https://github.com/espressomd/espresso/pull/3427
Patch0:         3427.patch
BuildRequires:  cmake
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
# Currently libboost_mpi-devel and hdf5 use different mpi versions
# BuildRequires:  hdf5-devel
BuildRequires:  %{mpiver}-devel
BuildRequires:  gsl-devel
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_mpi-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  hdf5-%{mpiver}-devel
BuildRequires:  zlib-devel
BuildRequires:  python3-h5py
%else
BuildRequires:  boost-devel
%endif
Obsoletes:      libEspresso4
Requires:       python3-numpy
Requires:       python3-h5py
# make sure rpm pulls in the right dependency
Requires:       libhdf5-%{mpiver}

%description
ESPResSo is a highly versatile software package for performing and analyzing
scientific Molecular Dynamics many-particle simulations of coarse-grained
atomistic or bead-spring models as they are used in soft-matter research in
physics, chemistry and molecular biology. It can be used to simulate systems
such as polymers, liquid crystals, colloids, ferrofluids and biological
systems, for example DNA and lipid membranes.

%prep
%setup -q -n %{pkgname}
%patch0 -p1

%build
source %{_libdir}/mpi/gcc/%{mpiver}/bin/mpivars.sh
# gh#espressomd/espresso#3396
%define _lto_cflags %{nil}

# overwrite .so linker flags on SUSE distros: drop --no-undefined
# we don't install {i,}pypresso scripts as they aren't needed when installing in /usr
%cmake \
  -DCMAKE_SHARED_LINKER_FLAGS='-Wl,--as-needed -Wl,-z,now' \
  -DLIBDIR=%{_lib} \
  -DPYTHON_EXECUTABLE=%{_bindir}/python3 \
  -DINSTALL_PYPRESSO=OFF
%make_jobs

%install
%cmake_install

# no devel package
rm -f %{buildroot}%{_libdir}/lib*.so

%check
# https://github.com/espressomd/espresso/issues/3315
%ifarch i586
%define testargs ARGS='-E collision_detection'
%endif
LD_LIBRARY_PATH='%{buildroot}/%{python3_sitearch}/espressomd::%{_libdir}/mpi/gcc/%{mpiver}/%{_lib}' make -C build check CTEST_OUTPUT_ON_FAILURE=1 %{?testargs:%{testargs}}

%files
%license COPYING
%doc README AUTHORS NEWS ChangeLog
%{python3_sitearch}/espressomd

%changelog
* Thu May 21 2020 Christoph Junghans <junghans@votca.org>
- Require: the right hdf5 library
* Mon May 11 2020 Christoph Junghans <junghans@votca.org>
- enable hdf5 support
- python3-numpy & python3-h5md are needed at runtime
* Tue Jan 21 2020 Christoph Junghans <junghans@votca.org>
- add 3427.patch to fix tests on i586
* Wed Jan 15 2020 Matej Cepl <mcepl@suse.com>
- Update to 4.1.2:
  - The interface has not been changed between ESPResSo 4.1.1 and
    4.1.2.
  - General corrections and improvements:
  - Remove correlation between the rotational noise and
    translational noise in the Langevin thermostat (#3355)
  - Fix a bug that may cause the wrong temperature to be set by
    the Langevin and DPD thermostats in the first time step
    after the system was altered from the Python level, e.g.,
    by changing particles or interactions (#3341)
  - Fix a bug that caused the DPD thermostat to generate an
    incorrect velocity distribution when used together with the
    Langevin thermostat (#3352)
  - Fix a bug in MMM2D and ELC with potential boundary
    conditions, where one of the correction factors was
    over-counted resulting in wrong energies (#3310)
  - Fix a bug that caused the wrong bonds to be deleted when
    removing particles from the system (#3356)
  - Fix an ambiguity in `ParticleSlice`: the values in the
    square brackets refer to particle ids, not array indices
    (#3367). This means the ill-defined syntax
    `system.part[0:-1]` is no longer valid. See the User Guide
    section on Setting up particles for more information.
  - Remove the mass prefactor in the `ComForce` observable and
    use the correct Particle ids in the
    `ParticleAngularVelocities` and `ParticleBodyVelocities`
    observables (#3380)
  - Fix a rounding error that caused debug builds of ESPResSo
    running with multiple MPI threads to crash when a particle
    was placed exactly on the boundary between two cells
    (#3377)
  - Fix `espressomd.has_features()` for the corner case where
    the list of all compiled-in features is passed as argument,
    returning ``False`` instead of ``True`` (#3318)
  - Refactor the random number generator code (#3349)
  - Documentation and tutorials corrections and improvements:
  - Improve documentation of Monte Carlo methods (#3254, #3330)
  - Build system and platform-related corrections and
    improvements:
  - List all Python dependencies in `requirements.txt` with the
    supported version numbers (#3300). Please note that most of
    them are optional.
  - Add `MPIEXEC_PREFLAGS` and `MPIEXEC_POSTFLAGS` to the
    command lines of parallel tests (#3221)
  - Add the `-oversubscribe` flag to the command lines of
    parallel tests running with OpenMPI v2.X to avoid exiting
    early from a Python test configured without `MAX_NUM_PROC`
    on a machine with a hyperthreaded CPU where OpenMPI is
    configured such that the number of threads cannot exceed
    the number of cores (#3335)
  - Refactor the CI, maintainer, Doxygen and pypresso shell
    scripts to make them more portable and support filepaths
    containing whitespaces (#3326, #3373)
  - Fix a nvcc compiler warning on the empty config (#3329)
  - Improved testing:
  - Add a test for ELC and MMM2D using analytic expressions of
    the force and energy (#3331)
  - Sped-up seven Python tests (#3319)
  - Fix a test that broke on s390x architectures with Fedora 31
    (#3312)
  - Fix tests that broke on i586 architectures with OpenSUSE
    Tumbleweed (#3327, #3358)
* Fri Nov 15 2019 Christoph Junghans <junghans@votca.org>
- Version bump to 4.1.1
  * Restore checkpointing mechanism for the steepest descent and NPT
    integrators, LB and NPT thermostats (#3245)
  * Increase the minimum MPI version to 3.0; OpenMPI versions 1.6.5 and
    lower are no longer supported (#3236)
  * Fix `Integrator.set_isotropic_npt()`: remove the silent conversion of
    the incorrect input parameter `direction=[0,0,0]` to `[1,1,1]` in the
    core; the function now throws an exception for fixed-volume boxes;
    this change is unlikely to break pypresso scripts since not providing
    a value to `direction` or providing `[1,1,1]` were the two standard
    ways to set up a box with all directions allowed to rescale (#3253)
  * Fix `Integrator.set_vv()`: this function failed to set the velocity
    Verlet integrator if the NPT integrator was active; this is now
    resolved (#3274)
  * Fix the random segmentation fault triggered by the removal of a
    particle with a bond or a virtual site relationship to another
    particle (#3288)
  * Fix `system.part.writevtk()`: the function now writes down all
    particles when using `types="all"` (#3290)
  * Disable the deprecated and broken ENGINE shear torque calculation
    feature; the feature will be completely removed from the core in
    the upcoming 4.2 release (#3277)
  * Fix unit conversion for the LB fluid viscosity (#3287)
* Tue Apr 30 2019 Christoph Junghans <junghans@votca.org>
- Version bump to 4.0.2
  * Corrections for bugs that may harm simulation results:
  * A sign error in tabulated interactions was corrected such that
    the force equals the negative gradient of the potential.
    (#2519,2520)
  * The flow field of the CPU lattice-Boltzmann implementation was
    deleted when aspects of the molecular dynamics cell grid were
    changed; E.g., when interactions, the skin or the parallelization
    setup were changed. ESPResSo now terminates with an error, when this
    happens. To avoid this, please setup the CPU lattice-Boltzmann after
    all other aspects of the system. The GPU LB is not affected in the
    4.0 release, but was affected in the current development branch.
    (#2728, #2736)
  * Corrected the force acting on LB Boundaries for the case of
    agrid and density not equal to 1 (#2624).
  * Corrected the cutoff calculation for the soft sphere interaction. In
    the previous implementation, the offset parameter was ignored.
    (#2505)
  * The "three point coupling" of particles to the lattice-Boltzmann
    method has been removed. While it works in most environments, for
    some compilers the calculation gives wrong values. This is likely
    caused by undefined behavior. A corrected implementation is
    available in ESPResSo's development branch. It cannot be safely
    backported to 4.0.2, because the code has diverged too far. (#2516,
    [#2517]) Users who did not explicitly activate this coupling via
    couple="3pt" are not affected.
  * The velocity of existing particles was changed when setting or
    changing the simulation time step (#2480)
  * Further changes:
  * Fixed the electrokinetic Python interface (#2486)
  * Correction to the installation instructions for mac (#2510)
  * Corrected file permissions (#2470)
  * Minor corrections and extensions to the test suite (#2477, #2552)
  * Fixed a dead-lock in the dipolar Barnes Hutt method on the GPU for
    recent NVIDIA cards such as RTX 2080 (#2719).
  * Restored Mayavi visualizer's API-compatibility with OpenGL
    visualizer (#2751)
* Fri Jan 25 2019 Christoph Junghans <junghans@votca.org>
- Version bump to 4.0.1
  * Many small bugfixes
- Drop 2255.patch, 2259.patch and 2265.patch - merged upstream
* Fri Sep 28 2018 Christoph Junghans <junghans@votca.org>
- added change from request #639007
  - rename package to python3-espressomd
  - install COPYING for all packages
  - change license to GPL-3.0-or-later
  - added sonum define
* Fri Sep  7 2018 junghans@votca.org
- Version bump to 4.0.0
- Rename pacakge to python-espressomd
- Dropped 1830.patch - merged upstream
- Dropped doc package - under rework in 4.0.0
- New features:
  - Reaction ensemble methods for the modelling of chemical reactions, including constant pH and Wang-Landau schemes.
  - Polarisable particles via the Drude-oscillator scheme.
  - Steepest-descent energy minimization scheme.
  - Methods for active particles (swimmer_reaction, dipolar swimmers).
  - GPU-accelerated P3M method for electrostatic interactions.
  - GPU-accelerated direct summation and Barnes-Hutt schemes for dipolar interactions under open boundary conditions.
  - Support for the electrostatic and magnetostatics method provided by the ScaFaCoS library.
  - Immersed boundary method for soft immersed objects in an LB fluid.
  - Virtual sites acting as inertialess tracers in an LB fluid usable as part of the immersed boundary method or independently.
  - New bonded quartic and Coulomb interactions.
  - Possibility to tune the skin parameter.
  - Support for saving to the h5md file format for molecular dynamics data.
  - Connection to the MD Analysis Python package.
  - A rotate_system command was added, which rotates the particle positions around the system’s center of mass.
- Added 2255.patch to fix numpy issue on i586
- Added 2259.patch to fix numpy issue on big-endian platforms
- Added 2265.patch to fix test on i586
* Mon Feb 12 2018 junghans@votca.org
- add 1830.patch to fix install
- update version 3.3.1+git20180203.f74064d
  * many many small fixes
  * support for newer cython
* Wed Oct 25 2017 junghans@votca.org
- adapt to new openlmi package - source mpivars.h during build
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Sep 29 2016 jengelh@inai.de
- RPM group fixup
* Wed Aug  3 2016 junghans@votca.org
- switched to cmake build-system
- build python module
- dropped header as they are for internal use only
- dropped pkg-config files as nothing depends on libs yet
- update version 3.3.1+git20160803.6ed0518.tar.gz
  * overhaul of buildsystem
  * many many small fixes
* Sun Jun 26 2016 i@marguerite.su
- fix boo#985147
  * there's a commit that removed redefinition of malloc and realloc
    which fixed build for gcc 6. but it's too hard to cherry pick, so
    update to the latest git version is a good idea
- there's no --without-mpi option left in configure.ac, so "-openmpi"
  sub-package is meaningless now (everything has openmpi support)
  and since there's no two main packages any more, "-common" sub-package
  is also meaningless now (and it doesn't contains data), merged.
- add sub-package: "-devel", "libEspresso0", "libEspressoTcl0"
- add generate_headers.rb to gather those .hpp that're really used
  into "-devel" sub-package
- create pkgconfig files
- add some texlive BuildRequires to build pdf documentation.
- update version 3.3.1+git20160622.6aa229c:
  * added edge statistics for meshes used by object-in-fluid
  * added pos_folded property
  * Adapted simple LB tests to current interface.
  * system.part.writevtk()
  * redesigned exclusions and added slice input
  * Scafacos: Add long range energy to correct place in energy data structure
  * Correction to scafacos energy calculation: Check cutoff in near field contrib
  * Scafacos: Sort out conditional compilation and cython includes
  * Scafacos: methods shared between electrostatics and dipolar calculations
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.3.1
  * A lot of changes; please read the NEWS file
* Tue Aug 12 2014 junghans@votca.org
- version bumped to 3.3.0
- Highlights of this release include:
  - Calculation of the electrokinetic equations via the ELECTROKINETICS feature,
  - the Shan/Chen method for multi component lattice Boltzmann fluids,
  - the P3M and MMM1D methods can now be computed on a GPU,
  - ESPResSo now has a rudimentary Python interface.
  For a complete list of the changes in the release, please refer to:
  http://download.savannah.gnu.org/releases/espressomd/NEWS
* Fri Feb  7 2014 junghans@votca.org
- build openmpi and non-mpi version
* Tue Feb  4 2014 junghans@votca.org
- initial commit
